<?php

namespace Drupal\file_defaults_by_type;

use Drupal\Component\Render\PlainTextOutput;

/**
 * Methods to get file location based on settings.
 */
trait FileLocationTrait {

  /**
   * Determines the URI for a file.
   *
   * @param array $settings
   *   The array of settings.
   * @param array $data
   *   An array of token objects to pass to Token::replace().
   *
   * @return string
   *   An unsanitized file directory URI with tokens replaced. The result of
   *   the token replacement is then converted to plain text and returned.
   *
   * @see \Drupal\file\Plugin\Field\FieldType::doGetUploadLocation()
   */
  protected function getUploadLocation(array $settings, array $data = []): string {
    $destination = trim($settings['file_directory'], '/');

    // Replace tokens. As the tokens might contain HTML we convert it to plain
    // text.
    $destination = PlainTextOutput::renderFromHtml(\Drupal::token()->replace($destination, $data));
    return $settings['uri_scheme'] . '://' . $destination;
  }

}
