<?php

declare(strict_types=1);

namespace Drupal\Tests\file_defaults_by_type\Traits;

use Drupal\file\Entity\File;

/**
 * Provides method for generating test files.
 */
trait TestsFilesTrait {

  /**
   * Creates a specific number of text files.
   *
   * File data based on index ($i), key starts from 1:
   *   - uuid: uuid-$i
   *   - uri: public://example-$i.txt
   *   - name: example-$i.txt.
   *
   * @param int $count
   *   The number of files to create.
   */
  public function generateTestFiles($count = 3): void {
    for ($i = 1; $i <= $count; $i++) {
      file_put_contents("public://example-$i.txt", $this->randomMachineName());
      $file = File::create([
        'uuid' => "uuid-$i",
        'uri' => "public://example-$i.txt",
        'name' => "example-$i.txt",
      ]);
      $file->save();
    }
    // Check that existing files are only generated.
    $this->assertFilesCount($count);
  }

  /**
   * Asserts how many File entities exist.
   *
   * @param int $count
   *   The expected number of entities.
   */
  protected function assertFilesCount(int $count): void {
    $this->assertCount($count, \Drupal::entityTypeManager()->getStorage('file')->loadMultiple());
  }

}
